@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.069';
+our $VERSION = '0.070';
 
 use base qw{Astro::Coord::ECI};
 
@@ -288,8 +288,9 @@ sub period {return 2360591.5968}	# 27.321662 * 86400
 	'Last quarter Moon');
 
     sub __quarter_name {
-	my ( $self, $quarter ) = @_;
-	return $quarters[$quarter];
+	my ( $self, $quarter, $name ) = @_;
+	$name ||= \@quarters;
+	return $name->[$quarter];
     }
 }
 
